==> jc-1.4.0.tar.gz: soot/baf/internal/BReturnInst.h <==
// public class soot.baf.internal.BReturnInst

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 75a736fe6c448796 soot_baf_internal_AbstractInst
// @dep_class 34018fa9b43e3c40 soot_baf_internal_AbstractOpTypeInst
// @dep_class 8edad795c6efddb3 soot_baf_internal_BReturnInst
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_baf_internal_AbstractOpTypeInst

#include "soot/baf/internal/AbstractOpTypeInst.h"

#ifndef _JC_soot_baf_internal_BReturnInst_H_
#define _JC_soot_baf_internal_BReturnInst_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Type$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_baf_internal_BReturnInst$sub_refs	_jc_soot_baf_internal_BReturnInst$sub_refs;
typedef struct _jc_soot_baf_internal_BReturnInst$sub_nonrefs	_jc_soot_baf_internal_BReturnInst$sub_nonrefs;
typedef struct _jc_soot_baf_internal_BReturnInst$refs	_jc_soot_baf_internal_BReturnInst$refs;
typedef struct _jc_soot_baf_internal_BReturnInst$nonrefs	_jc_soot_baf_internal_BReturnInst$nonrefs;
typedef struct _jc_soot_baf_internal_BReturnInst$object	_jc_soot_baf_internal_BReturnInst$object;

typedef const struct _jc_soot_baf_internal_BReturnInst$vmethods	_jc_soot_baf_internal_BReturnInst$vmethods;
typedef const struct _jc_soot_baf_internal_BReturnInst$vtable	_jc_soot_baf_internal_BReturnInst$vtable;
typedef const struct _jc_soot_baf_internal_BReturnInst$vtype	_jc_soot_baf_internal_BReturnInst$vtype;

// Constructors
extern void _jc_soot_baf_internal_BReturnInst$method$_init$39d637909e460d2e(_jc_env *, struct _jc_soot_baf_internal_BReturnInst$object *, struct _jc_soot_Type$object *);

// Virtual methods
extern void _jc_soot_baf_internal_BReturnInst$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_baf_internal_BReturnInst$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_baf_internal_BReturnInst$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_baf_internal_BReturnInst$object *);
extern jboolean _jc_soot_baf_internal_BReturnInst$method$fallsThrough$09e8b0d6b0c9d1bf(_jc_env *, struct _jc_soot_baf_internal_BReturnInst$object *);
extern jint _jc_soot_baf_internal_BReturnInst$method$getInCount$56a53206ce41ebab(_jc_env *, struct _jc_soot_baf_internal_BReturnInst$object *);
extern jint _jc_soot_baf_internal_BReturnInst$method$getInMachineCount$53f8938c85f21ad5(_jc_env *, struct _jc_soot_baf_internal_BReturnInst$object *);
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_BReturnInst$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_baf_internal_BReturnInst$object *);
extern jint _jc_soot_baf_internal_BReturnInst$method$getOutCount$de2aea04cd3e0d65(_jc_env *, struct _jc_soot_baf_internal_BReturnInst$object *);
extern jint _jc_soot_baf_internal_BReturnInst$method$getOutMachineCount$382bb5439d011100(_jc_env *, struct _jc_soot_baf_internal_BReturnInst$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_baf_internal_BReturnInst$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_baf_internal_BReturnInst$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_baf_internal_BReturnInst$method_info$fallsThrough$09e8b0d6b0c9d1bf;
extern _jc_method _jc_soot_baf_internal_BReturnInst$method_info$getInCount$56a53206ce41ebab;
extern _jc_method _jc_soot_baf_internal_BReturnInst$method_info$getInMachineCount$53f8938c85f21ad5;
extern _jc_method _jc_soot_baf_internal_BReturnInst$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_baf_internal_BReturnInst$method_info$getOutCount$de2aea04cd3e0d65;
extern _jc_method _jc_soot_baf_internal_BReturnInst$method_info$getOutMachineCount$382bb5439d011100;

// Virtual methods structure
struct _jc_soot_baf_internal_BReturnInst$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_baf_internal_BReturnInst$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_baf_internal_BReturnInst$object *);
	jboolean	(*fallsThrough$09e8b0d6b0c9d1bf)(_jc_env *, struct _jc_soot_baf_internal_BReturnInst$object *);
	jint	(*getInCount$56a53206ce41ebab)(_jc_env *, struct _jc_soot_baf_internal_BReturnInst$object *);
	jint	(*getInMachineCount$53f8938c85f21ad5)(_jc_env *, struct _jc_soot_baf_internal_BReturnInst$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_baf_internal_BReturnInst$object *);
	jint	(*getOutCount$de2aea04cd3e0d65)(_jc_env *, struct _jc_soot_baf_internal_BReturnInst$object *);
	jint	(*getOutMachineCount$382bb5439d011100)(_jc_env *, struct _jc_soot_baf_internal_BReturnInst$object *);
};

// Vtable
struct _jc_soot_baf_internal_BReturnInst$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_baf_internal_AbstractInst$vmethods	soot_baf_internal_AbstractInst;
	_jc_soot_baf_internal_AbstractOpTypeInst$vmethods	soot_baf_internal_AbstractOpTypeInst;
	_jc_soot_baf_internal_BReturnInst$vmethods	soot_baf_internal_BReturnInst;
};

// Vtype
struct _jc_soot_baf_internal_BReturnInst$vtype {
	_jc_type			type;
	_jc_soot_baf_internal_BReturnInst$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_internal_BReturnInst$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_baf_internal_BReturnInst$refs {
    _jc_soot_baf_internal_BReturnInst$sub_refs	soot_baf_internal_BReturnInst;
    _jc_soot_baf_internal_AbstractOpTypeInst$sub_refs	soot_baf_internal_AbstractOpTypeInst;
    _jc_soot_baf_internal_AbstractInst$sub_refs	soot_baf_internal_AbstractInst;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_internal_BReturnInst$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_internal_BReturnInst$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_baf_internal_AbstractInst$sub_nonrefs	soot_baf_internal_AbstractInst;
    _jc_soot_baf_internal_AbstractOpTypeInst$sub_nonrefs	soot_baf_internal_AbstractOpTypeInst;
    _jc_soot_baf_internal_BReturnInst$sub_nonrefs	soot_baf_internal_BReturnInst;
};

// Object instance structure
struct _jc_soot_baf_internal_BReturnInst$object {
	_jc_soot_baf_internal_BReturnInst$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_internal_BReturnInst$vtype	*vtype;
	_jc_soot_baf_internal_BReturnInst$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_internal_BReturnInst$vtype _jc_soot_baf_internal_BReturnInst$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_internal_BReturnInst, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_internal_BReturnInst$class_object;

#endif	/* _JC_soot_baf_internal_BReturnInst_H_ */

==> jc-1.4.6.tar.gz: soot/baf/internal/BReturnInst.h <==
// public class soot.baf.internal.BReturnInst

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 75a736fe6c448796 soot_baf_internal_AbstractInst
// @dep_class 34018fa9b43e3c40 soot_baf_internal_AbstractOpTypeInst
// @dep_class 8edad795c6efddb3 soot_baf_internal_BReturnInst
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_baf_internal_AbstractOpTypeInst

#include "soot/baf/internal/AbstractOpTypeInst.h"

#ifndef _JC_soot_baf_internal_BReturnInst_H_
#define _JC_soot_baf_internal_BReturnInst_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Type$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_baf_internal_BReturnInst$sub_refs	_jc_soot_baf_internal_BReturnInst$sub_refs;
typedef struct _jc_soot_baf_internal_BReturnInst$sub_nonrefs	_jc_soot_baf_internal_BReturnInst$sub_nonrefs;
typedef struct _jc_soot_baf_internal_BReturnInst$refs	_jc_soot_baf_internal_BReturnInst$refs;
typedef struct _jc_soot_baf_internal_BReturnInst$nonrefs	_jc_soot_baf_internal_BReturnInst$nonrefs;
typedef struct _jc_soot_baf_internal_BReturnInst$object	_jc_soot_baf_internal_BReturnInst$object;

typedef const struct _jc_soot_baf_internal_BReturnInst$vmethods	_jc_soot_baf_internal_BReturnInst$vmethods;
typedef const struct _jc_soot_baf_internal_BReturnInst$vtable	_jc_soot_baf_internal_BReturnInst$vtable;
typedef const struct _jc_soot_baf_internal_BReturnInst$vtype	_jc_soot_baf_internal_BReturnInst$vtype;

// Constructors
extern void _jc_soot_baf_internal_BReturnInst$method$_init$39d637909e460d2e(_jc_env *, struct _jc_soot_baf_internal_BReturnInst$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_baf_internal_BReturnInst$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_baf_internal_BReturnInst$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_baf_internal_BReturnInst$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_baf_internal_BReturnInst$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_baf_internal_BReturnInst$method$fallsThrough$09e8b0d6b0c9d1bf(_jc_env *, struct _jc_soot_baf_internal_BReturnInst$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_internal_BReturnInst$method$getInCount$56a53206ce41ebab(_jc_env *, struct _jc_soot_baf_internal_BReturnInst$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_internal_BReturnInst$method$getInMachineCount$53f8938c85f21ad5(_jc_env *, struct _jc_soot_baf_internal_BReturnInst$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_BReturnInst$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_baf_internal_BReturnInst$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_internal_BReturnInst$method$getOutCount$de2aea04cd3e0d65(_jc_env *, struct _jc_soot_baf_internal_BReturnInst$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_internal_BReturnInst$method$getOutMachineCount$382bb5439d011100(_jc_env *, struct _jc_soot_baf_internal_BReturnInst$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_baf_internal_BReturnInst$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_baf_internal_BReturnInst$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_baf_internal_BReturnInst$method_info$fallsThrough$09e8b0d6b0c9d1bf;
extern _jc_method _jc_soot_baf_internal_BReturnInst$method_info$getInCount$56a53206ce41ebab;
extern _jc_method _jc_soot_baf_internal_BReturnInst$method_info$getInMachineCount$53f8938c85f21ad5;
extern _jc_method _jc_soot_baf_internal_BReturnInst$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_baf_internal_BReturnInst$method_info$getOutCount$de2aea04cd3e0d65;
extern _jc_method _jc_soot_baf_internal_BReturnInst$method_info$getOutMachineCount$382bb5439d011100;

// Virtual methods structure
struct _jc_soot_baf_internal_BReturnInst$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_baf_internal_BReturnInst$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_baf_internal_BReturnInst$object *) _JC_JCNI_ATTR;
	jboolean	(*fallsThrough$09e8b0d6b0c9d1bf)(_jc_env *, struct _jc_soot_baf_internal_BReturnInst$object *) _JC_JCNI_ATTR;
	jint	(*getInCount$56a53206ce41ebab)(_jc_env *, struct _jc_soot_baf_internal_BReturnInst$object *) _JC_JCNI_ATTR;
	jint	(*getInMachineCount$53f8938c85f21ad5)(_jc_env *, struct _jc_soot_baf_internal_BReturnInst$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_baf_internal_BReturnInst$object *) _JC_JCNI_ATTR;
	jint	(*getOutCount$de2aea04cd3e0d65)(_jc_env *, struct _jc_soot_baf_internal_BReturnInst$object *) _JC_JCNI_ATTR;
	jint	(*getOutMachineCount$382bb5439d011100)(_jc_env *, struct _jc_soot_baf_internal_BReturnInst$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_baf_internal_BReturnInst$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_baf_internal_AbstractInst$vmethods	soot_baf_internal_AbstractInst;
	_jc_soot_baf_internal_AbstractOpTypeInst$vmethods	soot_baf_internal_AbstractOpTypeInst;
	_jc_soot_baf_internal_BReturnInst$vmethods	soot_baf_internal_BReturnInst;
};

// Vtype
struct _jc_soot_baf_internal_BReturnInst$vtype {
	_jc_type			type;
	_jc_soot_baf_internal_BReturnInst$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_internal_BReturnInst$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_baf_internal_BReturnInst$refs {
    _jc_soot_baf_internal_BReturnInst$sub_refs	soot_baf_internal_BReturnInst;
    _jc_soot_baf_internal_AbstractOpTypeInst$sub_refs	soot_baf_internal_AbstractOpTypeInst;
    _jc_soot_baf_internal_AbstractInst$sub_refs	soot_baf_internal_AbstractInst;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_internal_BReturnInst$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_internal_BReturnInst$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_baf_internal_AbstractInst$sub_nonrefs	soot_baf_internal_AbstractInst;
    _jc_soot_baf_internal_AbstractOpTypeInst$sub_nonrefs	soot_baf_internal_AbstractOpTypeInst;
    _jc_soot_baf_internal_BReturnInst$sub_nonrefs	soot_baf_internal_BReturnInst;
};

// Object instance structure
struct _jc_soot_baf_internal_BReturnInst$object {
	_jc_soot_baf_internal_BReturnInst$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_internal_BReturnInst$vtype	*vtype;
	_jc_soot_baf_internal_BReturnInst$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_internal_BReturnInst$vtype _jc_soot_baf_internal_BReturnInst$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_internal_BReturnInst, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_internal_BReturnInst$class_object;

#endif	/* _JC_soot_baf_internal_BReturnInst_H_ */
